@@ -1,9 +1,10 @@
 .onLoad <- function(libname, pkgname) {
   op <- options()
   op.mat <- list(
-    mat.pretty.print = TRUE,
-    mat.dot.row = 4L,
-    mat.dot.col = 4L
+    mat.sep = ",",
+    pprint.rowdots = 4L,
+    pprint.coldots = 4L,
+    atleast_2d = TRUE
   )
   toset <- !(names(op.mat) %in% names(op))
   if(any(toset)) options(op.mat[toset])
